@@ -4,6 +4,7 @@
 import collections
 import copy
 import json
+import os
 import pathlib
 import re
 import subprocess
@@ -87,34 +88,13 @@ class Dependency:
                                         ("unused", self.unused)])
 
 
-_MEM_ADDRESS_RE = re.compile(r'^\s*\(([^)]*)\)\s*$')
-
-
-def _strip_mem_address(text: str) -> str:
-    r"""
-    Strip the space and brackets from the mem address in the output.
-
-    :param text: to be stripped
-    :return: bare mem address
-
-    >>> _strip_mem_address('(0x00007f9a1a329000)')
-    '0x00007f9a1a329000'
-
-    >>> _strip_mem_address(' (0x00007f9a1a329000) ')
-    '0x00007f9a1a329000'
-
-    >>> _strip_mem_address('\t(0x00007f9a1a329000)\t')
-    '0x00007f9a1a329000'
-    """
-    mtch = _MEM_ADDRESS_RE.match(text)
-    if not mtch:
-        raise RuntimeError(("Unexpected mem address. Expected to match {}, "
-                            "but got: {!r}").format(_MEM_ADDRESS_RE.pattern,
-                                                    text))
-
-    return mtch.group(1)
+_LDD_ARROW_OUTPUT_RE = re.compile(
+    r"(?P<soname>.+)\s=>\s(?P<dep_path>.*)\s\(?(?P<mem_address>\w*)\)?")
+_LDD_NON_ARROW_OUTPUT_RE = re.compile(
+    r"(?P<dep_path>.+)\s\(?(?P<mem_address>\w*)\)?")
 
 
+# pylint: disable=too-many-branches
 def _parse_line(line: str) -> Optional[Dependency]:
     """
     Parse single line of ldd output.
@@ -123,8 +103,6 @@ def _parse_line(line: str) -> Optional[Dependency]:
     :return: dependency or None if line was empty
 
     """
-    found = not 'not found' in line
-    parts = [part.strip() for part in line.split(' ')]
     # pylint: disable=line-too-long
     # There are two types of outputs for a dependency, with or without soname.
     # The VDSO is a special case (see https://man7.org/linux/man-pages/man7/vdso.7.html)
@@ -137,51 +115,55 @@ def _parse_line(line: str) -> Optional[Dependency]:
     # with soname but not found: 'libboost_program_options.so.1.62.0 => not found'
     # with soname but without rpath: 'linux-vdso.so.1 =>  (0x00007ffd7c7fd000)'
     # pylint: enable=line-too-long
+    found = not 'not found' in line
+    soname = None
+    dep_path = None
+    mem_address = None
     if '=>' in line:
-        if len(parts) != 4:
-            raise RuntimeError(
-                "Expected 4 parts in the line but found {}: {}".format(
-                    len(parts), line))
-
-        soname = None
-        dep_path = None
-        mem_address = None
+        mtch = _LDD_ARROW_OUTPUT_RE.match(line)
+        if not mtch:
+            raise RuntimeError(("Unexpected ldd output. Expected to match {}, "
+                                "but got: {!r}").format(
+                                    _LDD_ARROW_OUTPUT_RE.pattern, line))
         if found:
-            soname = parts[0]
-            if parts[2] != '':
-                dep_path = pathlib.Path(parts[2])
-
-            mem_address = _strip_mem_address(text=parts[3])
+            soname = mtch["soname"]
+            if mtch["dep_path"]:
+                dep_path = pathlib.Path(mtch["dep_path"])
+            if mtch["mem_address"]:
+                mem_address = mtch["mem_address"]
         else:
-            if "/" in parts[0]:
-                dep_path = pathlib.Path(parts[0])
+            if os.sep in mtch["soname"]:
+                # This is a special case where the dep_path comes before the
+                # arrow and we have no soname
+                dep_path = pathlib.Path(mtch["soname"])
             else:
-                soname = parts[0]
-
-        return Dependency(
-            soname=soname, path=dep_path, found=found, mem_address=mem_address)
+                soname = mtch["soname"]
     else:
-        if len(parts) != 2:
-            # Please see https://github.com/Parquery/pylddwrap/pull/14
-            if 'no version information available' in line:
-                return None
+        # Please see https://github.com/Parquery/pylddwrap/pull/14
+        if 'no version information available' in line:
+            return None
 
-            raise RuntimeError(
-                "Expected 2 parts in the line but found {}: {}".format(
-                    len(parts), line))
-
-        if parts[0].startswith('linux-vdso'):
-            soname = parts[0]
-            path = None
+        mtch = _LDD_NON_ARROW_OUTPUT_RE.match(line)
+        if not mtch:
+            raise RuntimeError(("Unexpected ldd output. Expected to match {}, "
+                                "but got: {!r}").format(
+                                    _LDD_NON_ARROW_OUTPUT_RE.pattern, line))
+        # Special case for linux-vdso
+        if mtch["dep_path"].startswith("linux-vdso"):
+            soname = mtch["dep_path"]
         else:
-            soname = None
-            path = pathlib.Path(parts[0])
+            dep_path = pathlib.Path(mtch["dep_path"])
 
-        return Dependency(
-            soname=soname,
-            path=path,
-            found=True,
-            mem_address=_strip_mem_address(text=parts[1]))
+        found = True
+        mem_address = mtch["mem_address"]
+
+    # Sanity check to see if it didn't parse garbage:
+    # dep_path should have at least a `/` somewhere in the filepath
+    if dep_path and os.sep not in str(dep_path):
+        raise RuntimeError("Unexpected library path: {}".format(dep_path))
+
+    return Dependency(
+        soname=soname, path=dep_path, found=found, mem_address=mem_address)
 
 
 @icontract.require(lambda path: path.is_file())
@@ -191,7 +173,9 @@ def list_dependencies(path: pathlib.Path,
     """
     Retrieve a list of dependencies of the given binary.
 
-    >>> path = pathlib.Path("/bin/ls")
+    >>> import shutil
+    >>> ls = shutil.which("ls")
+    >>> path = pathlib.Path(ls)
     >>> deps = list_dependencies(path=path)
     >>> deps[0].soname
     'linux-vdso.so.1'
