@@ -2,6 +2,7 @@
 """Test lddwrap."""
 # pylint: disable=missing-docstring,too-many-public-methods
 import pathlib
+import shutil
 import tempfile
 import unittest
 from typing import Any, List, Optional
@@ -10,6 +11,12 @@ import lddwrap
 
 import tests
 
+# Some distros like NixOS does not have binaries on /bin.
+# Instead of hardcoding them, try to get them from PATH
+# using shutil.which function.
+DIR = shutil.which("dir") or "/bin/dir"
+PWD = shutil.which("pwd") or "/bin/pwd"
+
 
 class DependencyDiff:
     """Represent a different between two dependencies."""
@@ -60,7 +67,10 @@ class TestParseOutputWithoutUnused(unittest.TestCase):
             "(0x00007f4b78462000)",
             "libz.so.1 => not found",
             "../build/debug/libextstr.so => not found",
-            "/home/user/lib/liblmdb.so => not found"
+            "/home/user/lib/liblmdb.so => not found",
+            "/home/u s e r/lib/liblmdb.so => not found",
+            "UnityPlayer.so => /home/user/games/q u d/./UnityPlayer.so "
+            "(0x00007f90f290f000)"
         ]
         # yapf: enable
 
@@ -114,7 +124,19 @@ class TestParseOutputWithoutUnused(unittest.TestCase):
                 path=pathlib.Path("/home/user/lib/liblmdb.so"),
                 found=False,
                 mem_address=None,
-                unused=None)
+                unused=None),
+            lddwrap.Dependency(
+                soname=None,
+                path=pathlib.Path("/home/u s e r/lib/liblmdb.so"),
+                found=False,
+                mem_address=None,
+                unused=None),
+            lddwrap.Dependency(
+                soname="UnityPlayer.so",
+                path=pathlib.Path("/home/user/games/q u d/./UnityPlayer.so"),
+                found=True,
+                mem_address="0x00007f90f290f000",
+                unused=None),
         ]
 
         for i, line in enumerate(lines):
@@ -137,9 +159,7 @@ class TestParseOutputWithoutUnused(unittest.TestCase):
             run_err = err
 
         self.assertIsNotNone(run_err)
-        self.assertEqual(
-            'Expected 2 parts in the line but found {}: {}'.format(
-                line.count(' ') + 1, line), str(run_err))
+        self.assertTrue(str(run_err).startswith("Unexpected library path:"))
 
     def test_parse_non_indented_line(self):
         """Lines without leading indentation, at this point in processing, are
@@ -187,7 +207,7 @@ class TestAgainstMockLdd(unittest.TestCase):
                 ]),
                 out_unused=''):
             deps = lddwrap.list_dependencies(
-                path=pathlib.Path('/bin/pwd'), unused=False)
+                path=pathlib.Path(PWD), unused=False)
 
             expected_deps = [
                 lddwrap.Dependency(
@@ -236,7 +256,7 @@ class TestAgainstMockLdd(unittest.TestCase):
                 out_unused=''):
             # pylint: enable=line-too-long
             deps = lddwrap.list_dependencies(
-                path=pathlib.Path('/bin/dir'), unused=False)
+                path=pathlib.Path(DIR), unused=False)
 
             expected_deps = [
                 lddwrap.Dependency(
@@ -307,7 +327,7 @@ class TestAgainstMockLdd(unittest.TestCase):
                 out_unused=''):
             # pylint: enable=line-too-long
             deps = lddwrap.list_dependencies(
-                path=pathlib.Path("/bin/dir"), unused=True)
+                path=pathlib.Path(DIR), unused=True)
 
             unused = [dep for dep in deps if dep.unused]
             self.assertListEqual([], unused)
@@ -329,7 +349,7 @@ class TestAgainstMockLdd(unittest.TestCase):
         ):
             # pylint: enable=line-too-long
             deps = lddwrap.list_dependencies(
-                path=pathlib.Path("/bin/dir"), unused=True)
+                path=pathlib.Path(DIR), unused=True)
 
             unused = [dep for dep in deps if dep.unused]
 
@@ -389,7 +409,7 @@ class TestSorting(unittest.TestCase):
 
             for attr in lddwrap.DEPENDENCY_ATTRIBUTES:
                 deps = lddwrap.list_dependencies(
-                    path=pathlib.Path("/bin/dir"), unused=True)
+                    path=pathlib.Path(DIR), unused=True)
 
                 # pylint: disable=protected-access
                 lddwrap._sort_dependencies_in_place(deps=deps, sort_by=attr)
